You are viewing a plain text version of this content. The canonical link for it is here.
Posted to java-dev@axis.apache.org by pi...@apache.org on 2007/03/30 21:54:23 UTC

svn commit: r524255 [5/6] - in /webservices/axis2/trunk/c: axiom/include/ axiom/src/attachments/ axiom/src/om/ axiom/src/parser/guththila/ axiom/src/parser/libxml2/ axiom/src/util/ guththila/include/ include/ modules/core/clientapi/ modules/core/contex...

Modified: webservices/axis2/trunk/c/woden/src/builder/woden_reader.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/builder/woden_reader.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/builder/woden_resolver.c (original)
+++ webservices/axis2/trunk/c/woden/src/builder/woden_resolver.c Fri Mar 30 12:54:08 2007
@@ -20,7 +20,7 @@
 #include <woden_wsdl10_reader.h>
 #include <woden_schema_constants.h>
 #include <woden_qname_util.h>
-#include <axis2_uri.h>
+#include <axutil_uri.h>
 #include <axutil_qname.h>
 
 #include "../wsdl20/woden_constants.h"
@@ -37,7 +37,7 @@
 #include <axiom_stax_builder.h>
 #include <axiom_xml_reader.h>
 #include <axiom_util.h>
-#include <axis2_utils.h>
+#include <axutil_utils.h>
 
 
 typedef struct woden_resolver_impl woden_resolver_impl_t;

Modified: webservices/axis2/trunk/c/woden/src/builder/wsdl10/woden_wsdl10_reader.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/builder/wsdl10/woden_wsdl10_reader.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/schema/woden_imported_schema.c (original)
+++ webservices/axis2/trunk/c/woden/src/schema/woden_imported_schema.c Fri Mar 30 12:54:08 2007
@@ -17,7 +17,7 @@
 
 #include <woden_imported_schema.h>
 #include <xml_schema.h>
-#include <axis2_uri.h>
+#include <axutil_uri.h>
 
 typedef struct woden_imported_schema_impl woden_imported_schema_impl_t;
 
@@ -32,7 +32,7 @@
     woden_obj_types_t obj_type;
     axutil_hash_t *methods;
     axutil_hash_t *super;
-    axis2_uri_t *f_schema_location;
+    axutil_uri_t *f_schema_location;
 };
 
 #define INTF_TO_IMPL(schema) \
@@ -62,9 +62,9 @@
 woden_imported_schema_set_location(
     void *schema,
     const axutil_env_t *env,
-    axis2_uri_t *location);
+    axutil_uri_t *location);
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_imported_schema_get_location(
     void *schema,
     const axutil_env_t *env);
@@ -232,7 +232,7 @@
 
     if (schema_impl->f_schema_location)
     {
-        axis2_uri_free(schema_impl->f_schema_location, env);
+        axutil_uri_free(schema_impl->f_schema_location, env);
         schema_impl->f_schema_location = NULL;
     }
 
@@ -327,7 +327,7 @@
 woden_imported_schema_set_location(
     void *schema,
     const axutil_env_t *env,
-    axis2_uri_t *location)
+    axutil_uri_t *location)
 {
     woden_imported_schema_impl_t *schema_impl = NULL;
 
@@ -336,14 +336,14 @@
 
     if (schema_impl->f_schema_location)
     {
-        axis2_uri_free(schema_impl->f_schema_location, env);
+        axutil_uri_free(schema_impl->f_schema_location, env);
         schema_impl->f_schema_location = NULL;
     }
-    schema_impl->f_schema_location = axis2_uri_clone(location, env);
+    schema_impl->f_schema_location = axutil_uri_clone(location, env);
     return AXIS2_SUCCESS;
 }
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_imported_schema_get_location(
     void *schema,
     const axutil_env_t *env)

Modified: webservices/axis2/trunk/c/woden/src/schema/woden_inlined_schema.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/schema/woden_inlined_schema.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/schema/woden_inlined_schema.c (original)
+++ webservices/axis2/trunk/c/woden/src/schema/woden_inlined_schema.c Fri Mar 30 12:54:08 2007
@@ -17,7 +17,7 @@
 
 #include <woden_inlined_schema.h>
 #include <xml_schema.h>
-#include <axis2_uri.h>
+#include <axutil_uri.h>
 
 typedef struct woden_inlined_schema_impl woden_inlined_schema_impl_t;
 

Modified: webservices/axis2/trunk/c/woden/src/schema/woden_schema.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/schema/woden_schema.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/schema/woden_schema.c (original)
+++ webservices/axis2/trunk/c/woden/src/schema/woden_schema.c Fri Mar 30 12:54:08 2007
@@ -30,7 +30,7 @@
     axutil_hash_t *super;
     woden_obj_types_t obj_type;
 
-    axis2_uri_t *f_namespc;
+    axutil_uri_t *f_namespc;
     xml_schema_t *f_schema_def;
     axis2_bool_t f_is_referenceable;
 };
@@ -56,9 +56,9 @@
 woden_schema_set_namespace(
     void *schema,
     const axutil_env_t *env,
-    axis2_uri_t *namespc);
+    axutil_uri_t *namespc);
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_schema_get_namespace(
     void *schema,
     const axutil_env_t *env);
@@ -147,7 +147,7 @@
 
     if (schema_impl->f_namespc)
     {
-        axis2_uri_free(schema_impl->f_namespc, env);
+        axutil_uri_free(schema_impl->f_namespc, env);
         schema_impl->f_namespc = NULL;
     }
 
@@ -265,7 +265,7 @@
 woden_schema_set_namespace(
     void *schema,
     const axutil_env_t *env,
-    axis2_uri_t *namespc)
+    axutil_uri_t *namespc)
 {
     woden_schema_impl_t *schema_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -278,15 +278,15 @@
 
     if (schema_impl->f_namespc)
     {
-        axis2_uri_free(schema_impl->f_namespc, env);
+        axutil_uri_free(schema_impl->f_namespc, env);
         schema_impl->f_namespc = NULL;
     }
-    schema_impl->f_namespc = axis2_uri_clone(namespc, env);
+    schema_impl->f_namespc = axutil_uri_clone(namespc, env);
 
     return AXIS2_SUCCESS;
 }
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_schema_get_namespace(
     void *schema,
     const axutil_env_t *env)
@@ -392,6 +392,6 @@
             "WODEN_SCHEMA", AXIS2_HASH_KEY_STRING));
 
     return schema_impl->f_namespc  ?
-            axis2_uri_to_string(schema_impl->f_namespc, env, AXIS2_URI_UNP_OMITUSERINFO) : NULL;
+            axutil_uri_to_string(schema_impl->f_namespc, env, AXIS2_URI_UNP_OMITUSERINFO) : NULL;
 }
 

Modified: webservices/axis2/trunk/c/woden/src/schema/woden_schema_constants.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/schema/woden_schema_constants.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/schema/woden_schema_constants.c (original)
+++ webservices/axis2/trunk/c/woden/src/schema/woden_schema_constants.c Fri Mar 30 12:54:08 2007
@@ -19,9 +19,9 @@
 #include <axutil_env.h>
 #include <axutil_error.h>
 #include <axutil_string.h>
-#include <axis2_utils.h>
+#include <axutil_utils.h>
 #include <axutil_hash.h>
-#include <axis2_uri.h>
+#include <axutil_uri.h>
 #include <axutil_qname.h>
 #include <woden.h>
 #include <woden_schema_constants.h>

Modified: webservices/axis2/trunk/c/woden/src/util/woden_om_util.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/util/woden_om_util.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/util/woden_om_util.c (original)
+++ webservices/axis2/trunk/c/woden/src/util/woden_om_util.c Fri Mar 30 12:54:08 2007
@@ -18,7 +18,7 @@
 #include "woden_om_util.h"
 #include <axutil_qname.h>
 #include <axiom_element.h>
-#include <axis2_uri.h>
+#include <axutil_uri.h>
 
 
 AXIS2_EXTERN axutil_qname_t * AXIS2_CALL
@@ -65,14 +65,14 @@
     axis2_char_t *namespc_uri_str,
     axutil_hash_t *namespcs)
 {
-    axis2_uri_t *ns_uri = NULL;
-    axis2_uri_t *uri = NULL;
+    axutil_uri_t *ns_uri = NULL;
+    axutil_uri_t *uri = NULL;
     axis2_char_t *ns_uri_str = NULL;
     axis2_char_t *tmp_prefix = NULL;
 
     ns_uri = axutil_hash_get(namespcs, prefix, AXIS2_HASH_KEY_STRING);
     if (ns_uri)
-        ns_uri_str = axis2_uri_to_string(ns_uri, env, AXIS2_URI_UNP_OMITUSERINFO);
+        ns_uri_str = axutil_uri_to_string(ns_uri, env, AXIS2_URI_UNP_OMITUSERINFO);
     if (ns_uri_str && 0 == axis2_strcmp(ns_uri_str, namespc_uri_str))
     {
         /* Namespace already registerd */
@@ -85,12 +85,12 @@
 
         temp = axis2_stracat(env, tmp_prefix, "_");
         ns_uri = axutil_hash_get(namespcs, temp, AXIS2_HASH_KEY_STRING);
-        ns_uri_str = axis2_uri_to_string(ns_uri, env, AXIS2_URI_UNP_OMITUSERINFO);
+        ns_uri_str = axutil_uri_to_string(ns_uri, env, AXIS2_URI_UNP_OMITUSERINFO);
         AXIS2_FREE(env->allocator, tmp_prefix);
         tmp_prefix = axis2_strdup(env, temp);
         AXIS2_FREE(env->allocator, temp);
     }
-    uri = axis2_uri_parse_string(env, namespc_uri_str);
+    uri = axutil_uri_parse_string(env, namespc_uri_str);
     axutil_hash_set(namespcs, prefix, AXIS2_HASH_KEY_STRING, uri);
 
     return AXIS2_SUCCESS;

Modified: webservices/axis2/trunk/c/woden/src/util/woden_om_util.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/util/woden_om_util.h?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/util/woden_om_util.h (original)
+++ webservices/axis2/trunk/c/woden/src/util/woden_om_util.h Fri Mar 30 12:54:08 2007
@@ -29,7 +29,7 @@
 #include <axutil_env.h>
 #include <axutil_error.h>
 #include <axutil_string.h>
-#include <axis2_utils.h>
+#include <axutil_utils.h>
 #include <axutil_hash.h>
 #include <axutil_qname.h>
 #include <woden.h>

Modified: webservices/axis2/trunk/c/woden/src/wsdl/woden_attr_extensible.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl/woden_attr_extensible.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl/woden_attr_extensible.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl/woden_attr_extensible.c Fri Mar 30 12:54:08 2007
@@ -17,7 +17,7 @@
 
 #include <woden_attr_extensible.h>
 #include <woden_xml_attr.h>
-#include <axis2_uri.h>
+#include <axutil_uri.h>
 #include <axutil_hash.h>
 
 typedef struct woden_attr_extensible_impl woden_attr_extensible_impl_t;
@@ -75,13 +75,13 @@
 woden_attr_extensible_get_ext_attrs_for_namespace(
     void *extensible,
     const axutil_env_t *env,
-    axis2_uri_t *namespc);
+    axutil_uri_t *namespc);
 
 axis2_bool_t AXIS2_CALL
 woden_attr_extensible_has_ext_attrs_for_namespace(
     void *extensible,
     const axutil_env_t *env,
-    axis2_uri_t *namespc);
+    axutil_uri_t *namespc);
 
 
 
@@ -358,7 +358,7 @@
 axutil_array_list_t *AXIS2_CALL
 woden_attr_extensible_get_ext_attrs_for_namespace(void *extensible,
         const axutil_env_t *env,
-        axis2_uri_t *namespc)
+        axutil_uri_t *namespc)
 {
     woden_attr_extensible_impl_t *extensible_impl = NULL;
     axis2_char_t *str_namespc = NULL;
@@ -371,7 +371,7 @@
     extensible_impl = INTF_TO_IMPL(axutil_hash_get(super,
             "WODEN_ATTR_EXTENSIBLE", AXIS2_HASH_KEY_STRING));
 
-    str_namespc = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+    str_namespc = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
     if (extensible_impl->temp_attrs)
     {
         int size = 0, i = 0;
@@ -403,7 +403,7 @@
 axis2_bool_t AXIS2_CALL
 woden_attr_extensible_has_ext_attrs_for_namespace(void *extensible,
         const axutil_env_t *env,
-        axis2_uri_t *namespc)
+        axutil_uri_t *namespc)
 {
     woden_attr_extensible_impl_t *extensible_impl = NULL;
     axis2_bool_t result = AXIS2_FALSE;
@@ -417,7 +417,7 @@
     extensible_impl = INTF_TO_IMPL(axutil_hash_get(super,
             "WODEN_ATTR_EXTENSIBLE", AXIS2_HASH_KEY_STRING));
 
-    str_namespc = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+    str_namespc = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
     for (index = axutil_hash_first(extensible_impl->f_ext_attrs, env); index;
             index = axutil_hash_next(env, index))
     {

Modified: webservices/axis2/trunk/c/woden/src/wsdl/woden_binding.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl/woden_binding.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl/woden_binding.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl/woden_binding.c Fri Mar 30 12:54:08 2007
@@ -42,7 +42,7 @@
     axutil_qname_t *f_qname;
     axutil_qname_t *f_interface_qname;
     void *f_interface;
-    axis2_uri_t *f_type;
+    axutil_uri_t *f_type;
     /*
      * Binding faults and operations may be referred to specifically by the qname represented by
      * their 'ref' attribute. This typically suggests a Map implementation keyed by 'ref' qname. 
@@ -91,7 +91,7 @@
     void *binding,
     const axutil_env_t *env);
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_binding_get_type(
     void *binding,
     const axutil_env_t *env);
@@ -140,7 +140,7 @@
 woden_binding_set_type(
     void *binding,
     const axutil_env_t *env,
-    axis2_uri_t *type);
+    axutil_uri_t *type);
 
 axis2_status_t AXIS2_CALL
 woden_binding_add_binding_fault_element(
@@ -618,7 +618,7 @@
 
     if (binding_impl->f_type)
     {
-        axis2_uri_free(binding_impl->f_type, env);
+        axutil_uri_free(binding_impl->f_type, env);
         binding_impl->f_type = NULL;
     }
 
@@ -819,7 +819,7 @@
     return binding_impl->f_interface;
 }
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_binding_get_type(
     void *binding,
     const axutil_env_t *env)
@@ -971,7 +971,7 @@
 woden_binding_set_type(
     void *binding,
     const axutil_env_t *env,
-    axis2_uri_t *type)
+    axutil_uri_t *type)
 {
     woden_binding_impl_t *binding_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -984,10 +984,10 @@
 
     if (binding_impl->f_type)
     {
-        axis2_uri_free(binding_impl->f_type, env);
+        axutil_uri_free(binding_impl->f_type, env);
         binding_impl->f_type = NULL;
     }
-    binding_impl->f_type = axis2_uri_clone(type, env);
+    binding_impl->f_type = axutil_uri_clone(type, env);
 
     return AXIS2_SUCCESS;
 }

Modified: webservices/axis2/trunk/c/woden/src/wsdl/woden_component_exts.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl/woden_component_exts.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl/woden_component_exts.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl/woden_component_exts.c Fri Mar 30 12:54:08 2007
@@ -17,7 +17,7 @@
 
 #include <woden_component_exts.h>
 #include <woden_wsdl_element.h>
-#include <axis2_uri.h>
+#include <axutil_uri.h>
 #include <axutil_hash.h>
 
 typedef struct woden_component_exts_impl woden_component_exts_impl_t;
@@ -30,7 +30,7 @@
 {
     woden_component_exts_t component_exts;
     void *f_parent_element;
-    axis2_uri_t *f_namespc;
+    axutil_uri_t *f_namespc;
 };
 
 #define INTF_TO_IMPL(component_exts) ((woden_component_exts_impl_t *) component_exts)
@@ -40,7 +40,7 @@
     void *component_exts,
     const axutil_env_t *envv);
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_component_exts_get_namespace(
     void *component_exts,
     const axutil_env_t *env);
@@ -55,7 +55,7 @@
     void *component_exts,
     const axutil_env_t *env,
     woden_wsdl_element_t *parent_el,
-    axis2_uri_t *namespc);
+    axutil_uri_t *namespc);
 
 AXIS2_EXTERN woden_component_exts_t * AXIS2_CALL
 woden_component_exts_create(
@@ -103,7 +103,7 @@
 
     if (component_exts_impl->f_namespc)
     {
-        axis2_uri_free(component_exts_impl->f_namespc, env);
+        axutil_uri_free(component_exts_impl->f_namespc, env);
         component_exts_impl->f_namespc = NULL;
     }
 
@@ -149,7 +149,7 @@
     return AXIS2_SUCCESS;
 }
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_component_exts_get_namespace(
     void *component_exts,
     const axutil_env_t *env)
@@ -178,7 +178,7 @@
     void *component_exts,
     const axutil_env_t *env,
     woden_wsdl_element_t *parent_el,
-    axis2_uri_t *namespc)
+    axutil_uri_t *namespc)
 {
     woden_component_exts_impl_t *component_exts_impl = NULL;
 

Modified: webservices/axis2/trunk/c/woden/src/wsdl/woden_element_decl.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl/woden_element_decl.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl/woden_element_decl.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl/woden_element_decl.c Fri Mar 30 12:54:08 2007
@@ -16,7 +16,7 @@
  */
 
 #include <woden_element_decl.h>
-#include <axis2_uri.h>
+#include <axutil_uri.h>
 #include <axutil_hash.h>
 
 typedef struct woden_element_decl_impl woden_element_decl_impl_t;
@@ -32,7 +32,7 @@
     axutil_hash_t *super;
 
     axutil_qname_t *f_qname;
-    axis2_uri_t *f_system;
+    axutil_uri_t *f_system;
     axis2_char_t *f_content_model;
     axutil_generic_obj_t *f_content;
 };
@@ -63,7 +63,7 @@
     void *decl,
     const axutil_env_t *env);
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_element_decl_get_system(
     void *decl,
     const axutil_env_t *env);
@@ -92,7 +92,7 @@
 woden_element_decl_set_system(
     void *decl,
     const axutil_env_t *env,
-    axis2_uri_t *type_system_uri);
+    axutil_uri_t *type_system_uri);
 
 axis2_status_t AXIS2_CALL
 woden_element_decl_set_content_model(
@@ -310,7 +310,7 @@
     return decl_impl->f_qname;
 }
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_element_decl_get_system(
     void *decl,
     const axutil_env_t *env)
@@ -393,7 +393,7 @@
 woden_element_decl_set_system(
     void *decl,
     const axutil_env_t *env,
-    axis2_uri_t *type_system_uri)
+    axutil_uri_t *type_system_uri)
 {
     woden_element_decl_impl_t *decl_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -406,7 +406,7 @@
 
     if (decl_impl->f_system)
     {
-        axis2_uri_free(decl_impl->f_system, env);
+        axutil_uri_free(decl_impl->f_system, env);
     }
     decl_impl->f_system = type_system_uri;
     return AXIS2_SUCCESS;

Modified: webservices/axis2/trunk/c/woden/src/wsdl/woden_element_extensible.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl/woden_element_extensible.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl/woden_element_extensible.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl/woden_element_extensible.c Fri Mar 30 12:54:08 2007
@@ -18,7 +18,7 @@
 #include <woden_element_extensible.h>
 #include <woden_ext_element.h>
 #include <woden_xml_attr.h>
-#include <axis2_uri.h>
+#include <axutil_uri.h>
 #include <axutil_hash.h>
 
 typedef struct woden_element_extensible_impl woden_element_extensible_impl_t;
@@ -81,7 +81,7 @@
 woden_element_extensible_has_ext_elements_for_namespace(
     void *extensible,
     const axutil_env_t *env,
-    axis2_uri_t *namespc);
+    axutil_uri_t *namespc);
 
 
 
@@ -372,7 +372,7 @@
 woden_element_extensible_has_ext_elements_for_namespace(
     void *extensible,
     const axutil_env_t *env,
-    axis2_uri_t *namespc)
+    axutil_uri_t *namespc)
 {
     woden_element_extensible_impl_t *extensible_impl = NULL;
     axis2_bool_t result = AXIS2_FALSE;
@@ -387,7 +387,7 @@
     extensible_impl = INTF_TO_IMPL(axutil_hash_get(super,
             "WODEN_ELEMENT_EXTENSIBLE", AXIS2_HASH_KEY_STRING));
 
-    ext_ns = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+    ext_ns = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
     size = axutil_array_list_size(extensible_impl->f_ext_elements, env);
     for (i = 0; i < size; i++)
     {

Modified: webservices/axis2/trunk/c/woden/src/wsdl/woden_feature.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl/woden_feature.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl/woden_feature.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl/woden_feature.c Fri Mar 30 12:54:08 2007
@@ -35,7 +35,7 @@
     woden_documentable_t *documentable;
     axutil_hash_t *super;
     axutil_hash_t *methods;
-    axis2_uri_t *f_ref;
+    axutil_uri_t *f_ref;
     axis2_bool_t f_required;
     void *f_parent;
 };
@@ -66,9 +66,9 @@
 woden_feature_set_ref(
     void *feature,
     const axutil_env_t *env,
-    axis2_uri_t *ref);
+    axutil_uri_t *ref);
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_feature_get_ref(
     void *feature,
     const axutil_env_t *env);
@@ -546,7 +546,7 @@
 
     if (feature_impl->f_ref)
     {
-        axis2_uri_free(feature_impl->f_ref, env);
+        axutil_uri_free(feature_impl->f_ref, env);
         feature_impl->f_ref = NULL;
     }
 
@@ -676,7 +676,7 @@
 woden_feature_set_ref(
     void *feature,
     const axutil_env_t *env,
-    axis2_uri_t *ref)
+    axutil_uri_t *ref)
 {
     woden_feature_impl_t *feature_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -688,14 +688,14 @@
 
     if (feature_impl->f_ref)
     {
-        axis2_uri_free(feature_impl->f_ref, env);
+        axutil_uri_free(feature_impl->f_ref, env);
         feature_impl->f_ref = NULL;
     }
-    feature_impl->f_ref = axis2_uri_clone(ref, env);
+    feature_impl->f_ref = axutil_uri_clone(ref, env);
     return AXIS2_SUCCESS;
 }
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_feature_get_ref(
     void *feature,
     const axutil_env_t *env)

Modified: webservices/axis2/trunk/c/woden/src/wsdl/woden_import.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl/woden_import.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl/woden_import.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl/woden_import.c Fri Mar 30 12:54:08 2007
@@ -36,7 +36,7 @@
     axutil_hash_t *super;
     axutil_hash_t *methods;
 
-    axis2_uri_t *f_namespc;
+    axutil_uri_t *f_namespc;
 };
 
 #define INTF_TO_IMPL(import) ((woden_import_impl_t *) import)
@@ -65,9 +65,9 @@
 woden_import_set_namespace(
     void *import,
     const axutil_env_t *env,
-    axis2_uri_t *ns_uri);
+    axutil_uri_t *ns_uri);
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_import_get_namespace(
     void *import,
     const axutil_env_t *env);
@@ -316,7 +316,7 @@
 
     if (import_impl->f_namespc)
     {
-        axis2_uri_free(import_impl->f_namespc, env);
+        axutil_uri_free(import_impl->f_namespc, env);
         import_impl->f_namespc = NULL;
     }
 
@@ -431,7 +431,7 @@
 woden_import_set_namespace(
     void *import,
     const axutil_env_t *env,
-    axis2_uri_t *ns_uri)
+    axutil_uri_t *ns_uri)
 {
     woden_import_impl_t *import_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -444,15 +444,15 @@
 
     if (import_impl->f_namespc)
     {
-        axis2_uri_free(import_impl->f_namespc, env);
+        axutil_uri_free(import_impl->f_namespc, env);
         import_impl->f_namespc = NULL;
     }
-    import_impl->f_namespc = axis2_uri_clone(ns_uri, env);
+    import_impl->f_namespc = axutil_uri_clone(ns_uri, env);
 
     return AXIS2_SUCCESS;
 }
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_import_get_namespace(
     void *import,
     const axutil_env_t *env)

Modified: webservices/axis2/trunk/c/woden/src/wsdl/woden_interface.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl/woden_interface.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl/woden_interface.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl/woden_interface.c Fri Mar 30 12:54:08 2007
@@ -113,7 +113,7 @@
 woden_interface_add_style_default_uri(
     void *interface,
     const axutil_env_t *env,
-    axis2_uri_t *uri);
+    axutil_uri_t *uri);
 
 void *AXIS2_CALL
 woden_interface_get_style_default(
@@ -831,7 +831,7 @@
 woden_interface_add_style_default_uri(
     void *interface,
     const axutil_env_t *env,
-    axis2_uri_t *uri)
+    axutil_uri_t *uri)
 {
     woden_interface_impl_t *interface_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -851,7 +851,7 @@
             return AXIS2_FAILURE;
         }
     }
-    axutil_array_list_add(interface_impl->f_style_default, env, axis2_uri_clone(
+    axutil_array_list_add(interface_impl->f_style_default, env, axutil_uri_clone(
                 uri, env));
 
     return AXIS2_SUCCESS;

Modified: webservices/axis2/trunk/c/woden/src/wsdl/woden_interface_op.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl/woden_interface_op.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl/woden_interface_op.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl/woden_interface_op.c Fri Mar 30 12:54:08 2007
@@ -38,7 +38,7 @@
     axutil_hash_t *super;
     axutil_hash_t *methods;
     axutil_qname_t *f_qname;
-    axis2_uri_t *f_msg_exchange_pattern;
+    axutil_uri_t *f_msg_exchange_pattern;
     axutil_array_list_t *f_style;
     axutil_array_list_t *f_msg_refs;
     axutil_array_list_t *f_fault_refs;
@@ -75,7 +75,7 @@
     void *interface_op,
     const axutil_env_t *env);
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_interface_op_get_msg_exchange_pattern(
     void *interface_op,
     const axutil_env_t *env);
@@ -114,9 +114,9 @@
 woden_interface_op_set_pattern(
     void *interface_op,
     const axutil_env_t *env,
-    axis2_uri_t *uri);
+    axutil_uri_t *uri);
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_interface_op_get_pattern(
     void *interface_op,
     const axutil_env_t *env);
@@ -125,13 +125,13 @@
 woden_interface_op_add_style_uri(
     void *interface_op,
     const axutil_env_t *env,
-    axis2_uri_t *uri);
+    axutil_uri_t *uri);
 
 axis2_status_t AXIS2_CALL
 woden_interface_op_remove_style_uri(
     void *interface_op,
     const axutil_env_t *env,
-    axis2_uri_t *uri);
+    axutil_uri_t *uri);
 
 axis2_status_t AXIS2_CALL
 woden_interface_op_add_interface_msg_ref_element(
@@ -730,7 +730,7 @@
 
     if (interface_op_impl->f_msg_exchange_pattern)
     {
-        axis2_uri_free(interface_op_impl->f_msg_exchange_pattern, env);
+        axutil_uri_free(interface_op_impl->f_msg_exchange_pattern, env);
         interface_op_impl->f_msg_exchange_pattern = NULL;
     }
 
@@ -905,7 +905,7 @@
     return interface_op_impl->f_qname;
 }
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_interface_op_get_msg_exchange_pattern(
     void *interface_op,
     const axutil_env_t *env)
@@ -1018,7 +1018,7 @@
 woden_interface_op_set_pattern(
     void *interface_op,
     const axutil_env_t *env,
-    axis2_uri_t *uri)
+    axutil_uri_t *uri)
 {
     woden_interface_op_impl_t *interface_op_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -1031,16 +1031,16 @@
 
     if (interface_op_impl->f_msg_exchange_pattern)
     {
-        axis2_uri_free(interface_op_impl->f_msg_exchange_pattern, env);
+        axutil_uri_free(interface_op_impl->f_msg_exchange_pattern, env);
         interface_op_impl->f_msg_exchange_pattern = NULL;
     }
-    interface_op_impl->f_msg_exchange_pattern = axis2_uri_clone(uri, env);
+    interface_op_impl->f_msg_exchange_pattern = axutil_uri_clone(uri, env);
 
 
     return AXIS2_SUCCESS;
 }
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_interface_op_get_pattern(
     void *interface_op,
     const axutil_env_t *env)
@@ -1060,7 +1060,7 @@
 woden_interface_op_add_style_uri(
     void *interface_op,
     const axutil_env_t *env,
-    axis2_uri_t *uri)
+    axutil_uri_t *uri)
 {
     woden_interface_op_impl_t *interface_op_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -1080,7 +1080,7 @@
             return AXIS2_FAILURE;
         }
     }
-    axutil_array_list_add(interface_op_impl->f_style, env, axis2_uri_clone(uri, env));
+    axutil_array_list_add(interface_op_impl->f_style, env, axutil_uri_clone(uri, env));
     return AXIS2_SUCCESS;
 }
 
@@ -1088,7 +1088,7 @@
 woden_interface_op_remove_style_uri(
     void *interface_op,
     const axutil_env_t *env,
-    axis2_uri_t *uri)
+    axutil_uri_t *uri)
 {
     woden_interface_op_impl_t *interface_op_impl = NULL;
     axutil_hash_t *super = NULL;

Modified: webservices/axis2/trunk/c/woden/src/wsdl/woden_property.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl/woden_property.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl/woden_property.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl/woden_property.c Fri Mar 30 12:54:08 2007
@@ -41,7 +41,7 @@
     axutil_hash_t *super;
     axutil_hash_t *methods;
     /* WSDL Component model data */
-    axis2_uri_t *f_ref;
+    axutil_uri_t *f_ref;
     axutil_generic_obj_t *f_value;
     woden_type_def_t *f_value_constraint;
     void *f_parent;
@@ -77,9 +77,9 @@
 woden_property_set_ref(
     void *property,
     const axutil_env_t *env,
-    axis2_uri_t *ref);
+    axutil_uri_t *ref);
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_property_get_ref(
     void *property,
     const axutil_env_t *env);
@@ -633,7 +633,7 @@
 
     if (property_impl->f_ref)
     {
-        axis2_uri_free(property_impl->f_ref, env);
+        axutil_uri_free(property_impl->f_ref, env);
         property_impl->f_ref = NULL;
     }
 
@@ -768,7 +768,7 @@
 woden_property_set_ref(
     void *property,
     const axutil_env_t *env,
-    axis2_uri_t *ref)
+    axutil_uri_t *ref)
 {
     woden_property_impl_t *property_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -780,14 +780,14 @@
 
     if (property_impl->f_ref)
     {
-        axis2_uri_free(property_impl->f_ref, env);
+        axutil_uri_free(property_impl->f_ref, env);
         property_impl->f_ref = NULL;
     }
-    property_impl->f_ref = axis2_uri_clone(ref, env);
+    property_impl->f_ref = axutil_uri_clone(ref, env);
     return AXIS2_SUCCESS;
 }
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_property_get_ref(
     void *property,
     const axutil_env_t *env)

Modified: webservices/axis2/trunk/c/woden/src/wsdl/woden_type_def.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl/woden_type_def.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl/woden_type_def.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl/woden_type_def.c Fri Mar 30 12:54:08 2007
@@ -33,7 +33,7 @@
     axutil_hash_t *super;
     axutil_hash_t *methods;
     axutil_qname_t *f_qname;
-    axis2_uri_t *f_system;
+    axutil_uri_t *f_system;
     axis2_char_t *f_content_model;
     axutil_generic_obj_t *f_content;
 };
@@ -70,9 +70,9 @@
 woden_type_def_set_system(
     void *type_def,
     const axutil_env_t *env,
-    axis2_uri_t *type_system_uri);
+    axutil_uri_t *type_system_uri);
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_type_def_get_system(
     void *type_def,
     const axutil_env_t *env);
@@ -374,7 +374,7 @@
 woden_type_def_set_system(
     void *type_def,
     const axutil_env_t *env,
-    axis2_uri_t *type_system_uri)
+    axutil_uri_t *type_system_uri)
 {
     woden_type_def_impl_t *type_def_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -393,7 +393,7 @@
     return AXIS2_SUCCESS;
 }
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_type_def_get_system(
     void *type_def,
     const axutil_env_t *env)

Modified: webservices/axis2/trunk/c/woden/src/wsdl/woden_types.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl/woden_types.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl/woden_types.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl/woden_types.c Fri Mar 30 12:54:08 2007
@@ -94,7 +94,7 @@
 woden_types_get_schemas_with_namespace(
     void *types,
     const axutil_env_t *env,
-    axis2_uri_t *namespc);
+    axutil_uri_t *namespc);
 
 axutil_array_list_t *AXIS2_CALL
 woden_types_get_inlined_schemas(
@@ -133,7 +133,7 @@
 woden_types_is_namespace_in_scope_with_namespace_uri(
     void *types,
     const axutil_env_t *env,
-    axis2_uri_t *namespc_uri);
+    axutil_uri_t *namespc_uri);
 
 axis2_bool_t AXIS2_CALL
 woden_types_is_namespace_in_scope_with_qname(
@@ -817,7 +817,7 @@
 woden_types_get_schemas_with_namespace(
     void *types,
     const axutil_env_t *env,
-    axis2_uri_t *namespc)
+    axutil_uri_t *namespc)
 {
     woden_types_impl_t *types_impl = NULL;
     int i = 0, size = 0;
@@ -830,7 +830,7 @@
             "WODEN_TYPES", AXIS2_HASH_KEY_STRING));
 
     if (namespc)
-        str_namespc = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+        str_namespc = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
     size = axutil_array_list_size(types_impl->f_schemas, env);
     for (i = 0; i < size; i++)
     {
@@ -1077,7 +1077,7 @@
 woden_types_is_namespace_in_scope_with_namespace_uri(
     void *types,
     const axutil_env_t *env,
-    axis2_uri_t *namespc_uri)
+    axutil_uri_t *namespc_uri)
 {
     woden_types_impl_t *types_impl = NULL;
     axis2_char_t *str_uri = NULL;
@@ -1090,7 +1090,7 @@
     types_impl = INTF_TO_IMPL(axutil_hash_get(super,
             "WODEN_TYPES", AXIS2_HASH_KEY_STRING));
 
-    str_uri = axis2_uri_to_string(namespc_uri, env, AXIS2_URI_UNP_OMITUSERINFO);
+    str_uri = axutil_uri_to_string(namespc_uri, env, AXIS2_URI_UNP_OMITUSERINFO);
     return woden_types_is_namespace_in_scope_with_namespace(types, env, str_uri);
 }
 
@@ -1102,7 +1102,7 @@
 {
     woden_types_impl_t *types_impl = NULL;
     axis2_char_t *str_uri = NULL;
-    axis2_uri_t *uri = NULL;
+    axutil_uri_t *uri = NULL;
     axutil_hash_t *super = NULL;
 
     AXIS2_ENV_CHECK(env, AXIS2_FAILURE);
@@ -1112,7 +1112,7 @@
             "WODEN_TYPES", AXIS2_HASH_KEY_STRING));
 
     str_uri = axutil_qname_get_uri(qname, env);
-    uri = axis2_uri_parse_string(env, str_uri);
+    uri = axutil_uri_parse_string(env, str_uri);
     return woden_types_is_namespace_in_scope_with_namespace_uri(types, env, uri);
 }
 

Modified: webservices/axis2/trunk/c/woden/src/wsdl/woden_wsdl_element.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl/woden_wsdl_element.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl/woden_wsdl_element.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl/woden_wsdl_element.c Fri Mar 30 12:54:08 2007
@@ -20,7 +20,7 @@
 #include <woden_attr_extensible.h>
 #include <woden_ext_element.h>
 #include <woden_xml_attr.h>
-#include <axis2_uri.h>
+#include <axutil_uri.h>
 #include <axutil_hash.h>
 
 typedef struct woden_wsdl_element_impl woden_wsdl_element_impl_t;
@@ -79,13 +79,13 @@
 woden_wsdl_element_get_ext_attrs_for_namespace(
     void *wsdl_element,
     const axutil_env_t *env,
-    axis2_uri_t *namespc);
+    axutil_uri_t *namespc);
 
 axis2_bool_t AXIS2_CALL
 woden_wsdl_element_has_ext_attrs_for_namespace(
     void *wsdl_element,
     const axutil_env_t *env,
-    axis2_uri_t *namespc);
+    axutil_uri_t *namespc);
 
 axis2_status_t AXIS2_CALL
 woden_wsdl_element_add_ext_element(
@@ -114,7 +114,7 @@
 woden_wsdl_element_has_ext_elements_for_namespace(
     void *wsdl_element,
     const axutil_env_t *env,
-    axis2_uri_t *namespc);
+    axutil_uri_t *namespc);
 
 axis2_status_t AXIS2_CALL
 woden_wsdl_element_add_ext_element(
@@ -143,7 +143,7 @@
 woden_wsdl_element_has_ext_elements_for_namespace(
     void *wsdl_element,
     const axutil_env_t *env,
-    axis2_uri_t *namespc);
+    axutil_uri_t *namespc);
 
 void *AXIS2_CALL
 woden_wsdl_element_get_element_extensible(
@@ -534,7 +534,7 @@
 woden_wsdl_element_get_ext_attrs_for_namespace(
     void *wsdl_element,
     const axutil_env_t *env,
-    axis2_uri_t *namespc)
+    axutil_uri_t *namespc)
 {
     woden_wsdl_element_impl_t *wsdl_element_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -553,7 +553,7 @@
 woden_wsdl_element_has_ext_attrs_for_namespace(
     void *wsdl_element,
     const axutil_env_t *env,
-    axis2_uri_t *namespc)
+    axutil_uri_t *namespc)
 {
     woden_wsdl_element_impl_t *wsdl_element_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -647,7 +647,7 @@
 woden_wsdl_element_has_ext_elements_for_namespace(
     void *wsdl_element,
     const axutil_env_t *env,
-    axis2_uri_t *namespc)
+    axutil_uri_t *namespc)
 {
     woden_wsdl_element_impl_t *wsdl_element_impl = NULL;
     axutil_hash_t *super = NULL;

Modified: webservices/axis2/trunk/c/woden/src/wsdl/woden_wsdl_obj.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl/woden_wsdl_obj.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl/woden_wsdl_obj.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl/woden_wsdl_obj.c Fri Mar 30 12:54:08 2007
@@ -54,13 +54,13 @@
 woden_wsdl_obj_get_component_exts_for_namespace(
     void *wsdl_obj,
     const axutil_env_t *env,
-    axis2_uri_t *namespc);
+    axutil_uri_t *namespc);
 
 axis2_status_t AXIS2_CALL
 woden_wsdl_obj_set_component_exts(
     void *wsdl_obj,
     const axutil_env_t *env,
-    axis2_uri_t *namespc,
+    axutil_uri_t *namespc,
     woden_component_exts_t *exts);
 
 static woden_wsdl_obj_t *
@@ -220,7 +220,7 @@
 woden_wsdl_obj_get_component_exts_for_namespace(
     void *wsdl_obj,
     const axutil_env_t *env,
-    axis2_uri_t *namespc)
+    axutil_uri_t *namespc)
 {
     woden_wsdl_obj_impl_t *wsdl_obj_impl = NULL;
     axis2_char_t *str_namespc = NULL;
@@ -231,7 +231,7 @@
     wsdl_obj_impl = INTF_TO_IMPL(axutil_hash_get(super,
             "WODEN_WSDL_OBJ", AXIS2_HASH_KEY_STRING));
 
-    str_namespc = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+    str_namespc = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
     return (woden_component_exts_t *)axutil_hash_get(wsdl_obj_impl->
             f_comp_exts, str_namespc, AXIS2_HASH_KEY_STRING);
 }
@@ -240,7 +240,7 @@
 woden_wsdl_obj_set_component_exts(
     void *wsdl_obj,
     const axutil_env_t *env,
-    axis2_uri_t *namespc,
+    axutil_uri_t *namespc,
     woden_component_exts_t *exts)
 {
     woden_wsdl_obj_impl_t *wsdl_obj_impl = NULL;
@@ -253,7 +253,7 @@
     wsdl_obj_impl = INTF_TO_IMPL(axutil_hash_get(super,
             "WODEN_WSDL_OBJ", AXIS2_HASH_KEY_STRING));
 
-    str_namespc = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+    str_namespc = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
     if (str_namespc)
     {
         if (exts)

Modified: webservices/axis2/trunk/c/woden/src/wsdl/woden_wsdl_ref.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl/woden_wsdl_ref.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl/woden_wsdl_ref.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl/woden_wsdl_ref.c Fri Mar 30 12:54:08 2007
@@ -32,7 +32,7 @@
     axutil_hash_t *super;
     woden_obj_types_t obj_type;
     axutil_array_list_t *f_documentation_elements;
-    axis2_uri_t *f_location;
+    axutil_uri_t *f_location;
     woden_desc_element_t *f_desc_element;
 };
 
@@ -53,7 +53,7 @@
     void *wsdl_ref,
     const axutil_env_t *env);
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_wsdl_ref_get_location(
     void *wsdl_ref,
     const axutil_env_t *env);
@@ -62,7 +62,7 @@
 woden_wsdl_ref_set_location(
     void *wsdl_ref,
     const axutil_env_t *env,
-    axis2_uri_t *loc_uri);
+    axutil_uri_t *loc_uri);
 
 void *AXIS2_CALL
 woden_wsdl_ref_get_desc_element(
@@ -283,7 +283,7 @@
     return AXIS2_SUCCESS;
 }
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_wsdl_ref_get_location(
     void *wsdl_ref,
     const axutil_env_t *env)
@@ -303,7 +303,7 @@
 woden_wsdl_ref_set_location(
     void *wsdl_ref,
     const axutil_env_t *env,
-    axis2_uri_t *loc_uri)
+    axutil_uri_t *loc_uri)
 {
     woden_wsdl_ref_impl_t *wsdl_ref_impl = NULL;
     axutil_hash_t *super = NULL;

Modified: webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_soap_address_exts.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_soap_address_exts.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_soap_address_exts.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_soap_address_exts.c Fri Mar 30 12:54:08 2007
@@ -39,7 +39,7 @@
     woden_obj_types_t obj_type;
 
     axutil_qname_t *qname;
-    axis2_uri_t *address;
+    axutil_uri_t *address;
 };
 
 #define INTF_TO_IMPL(address_exts) ((woden_wsdl10_soap_address_exts_impl_t *) address_exts)
@@ -68,9 +68,9 @@
 woden_wsdl10_soap_address_exts_set_soap_address(
     void *address_exts,
     const axutil_env_t *env,
-    axis2_uri_t *address);
+    axutil_uri_t *address);
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_wsdl10_soap_address_exts_get_soap_address(
     void *address_exts,
     const axutil_env_t *env);
@@ -254,7 +254,7 @@
 
     if (address_exts_impl->address)
     {
-        axis2_uri_free(address_exts_impl->address, env);
+        axutil_uri_free(address_exts_impl->address, env);
         address_exts_impl->address = NULL;
     }
 
@@ -351,7 +351,7 @@
 woden_wsdl10_soap_address_exts_set_soap_address(
     void *address_exts,
     const axutil_env_t *env,
-    axis2_uri_t *address)
+    axutil_uri_t *address)
 {
     woden_wsdl10_soap_address_exts_impl_t *address_exts_impl = NULL;
 
@@ -359,13 +359,13 @@
     AXIS2_PARAM_CHECK(env->error, address, AXIS2_FAILURE);
     address_exts_impl = INTF_TO_IMPL(address_exts);
 
-    address_exts_impl->address = axis2_uri_clone(address, env);
+    address_exts_impl->address = axutil_uri_clone(address, env);
 
     return AXIS2_SUCCESS;
 }
 
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_wsdl10_soap_address_exts_get_soap_address(
     void *address_exts,
     const axutil_env_t *env)

Modified: webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_binding_exts.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_binding_exts.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_binding_exts.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_binding_exts.c Fri Mar 30 12:54:08 2007
@@ -66,12 +66,12 @@
     void *binding_exts,
     const axutil_env_t *env);
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_wsdl10_soap_binding_exts_get_soap_underlying_protocol(
     void *binding_exts,
     const axutil_env_t *env);
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_wsdl10_soap_binding_exts_get_soap_mep_default(
     void *binding_exts,
     const axutil_env_t *env);
@@ -385,7 +385,7 @@
             NULL;
 }
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_wsdl10_soap_binding_exts_get_soap_underlying_protocol(
     void *binding_exts,
     const axutil_env_t *env)
@@ -408,7 +408,7 @@
     return protocol  ? WODEN_URI_ATTR_GET_URI(protocol, env) : NULL;
 }
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_wsdl10_soap_binding_exts_get_soap_mep_default(
     void *binding_exts,
     const axutil_env_t *env)

Modified: webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_binding_op_exts.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_binding_op_exts.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_binding_op_exts.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_binding_op_exts.c Fri Mar 30 12:54:08 2007
@@ -39,7 +39,7 @@
     woden_obj_types_t obj_type;
 
     axutil_qname_t *qname;
-    axis2_uri_t *action;
+    axutil_uri_t *action;
 };
 
 #define INTF_TO_IMPL(binding_op_exts) ((woden_wsdl10_soap_binding_op_exts_impl_t *) binding_op_exts)
@@ -64,7 +64,7 @@
     void *binding_op_exts,
     const axutil_env_t *env);
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_wsdl10_soap_binding_op_exts_get_soap_mep(
     void *binding_op_exts,
     const axutil_env_t *env);
@@ -73,9 +73,9 @@
 woden_wsdl10_soap_binding_op_exts_set_soap_action(
     void *binding_op_exts,
     const axutil_env_t *env,
-    axis2_uri_t *action);
+    axutil_uri_t *action);
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_wsdl10_soap_binding_op_exts_get_soap_action(
     void *binding_op_exts,
     const axutil_env_t *env);
@@ -264,7 +264,7 @@
 
     if (binding_op_exts_impl->action)
     {
-        axis2_uri_free(binding_op_exts_impl->action, env);
+        axutil_uri_free(binding_op_exts_impl->action, env);
         binding_op_exts_impl->action = NULL;
     }
 
@@ -357,7 +357,7 @@
     return AXIS2_SUCCESS;
 }
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_wsdl10_soap_binding_op_exts_get_soap_mep(
     void *binding_op_exts,
     const axutil_env_t *env)
@@ -385,7 +385,7 @@
 woden_wsdl10_soap_binding_op_exts_set_soap_action(
     void *binding_op_exts,
     const axutil_env_t *env,
-    axis2_uri_t *action)
+    axutil_uri_t *action)
 {
     woden_wsdl10_soap_binding_op_exts_impl_t *binding_op_exts_impl = NULL;
 
@@ -393,13 +393,13 @@
     AXIS2_PARAM_CHECK(env->error, action, AXIS2_FAILURE);
     binding_op_exts_impl = INTF_TO_IMPL(binding_op_exts);
 
-    binding_op_exts_impl->action = axis2_uri_clone(action, env);
+    binding_op_exts_impl->action = axutil_uri_clone(action, env);
 
     return AXIS2_SUCCESS;
 }
 
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_wsdl10_soap_binding_op_exts_get_soap_action(
     void *binding_op_exts,
     const axutil_env_t *env)

Modified: webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_constants.h
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_constants.h?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_constants.h (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_constants.h Fri Mar 30 12:54:08 2007
@@ -24,7 +24,7 @@
  *          Constants for XML Soap elements, attributes and URIs.
  */
  
-#include <axis2_utils.h>
+#include <axutil_utils.h>
 
 #ifdef __cplusplus
 extern "C" 

Modified: webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_header_block.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_header_block.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_header_block.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_header_block.c Fri Mar 30 12:54:08 2007
@@ -180,7 +180,7 @@
 woden_wsdl10_soap_header_block_get_ext_attrs_for_namespace(
     void *header_block,
     const axutil_env_t *env,
-    axis2_uri_t *namespc);
+    axutil_uri_t *namespc);
 
 axutil_array_list_t *AXIS2_CALL
 woden_wsdl10_soap_header_block_get_ext_attrs(
@@ -191,7 +191,7 @@
 woden_wsdl10_soap_header_block_has_ext_attrs_for_namespace(
     void *header_block,
     const axutil_env_t *env,
-    axis2_uri_t *namespc);
+    axutil_uri_t *namespc);
 
 axis2_status_t AXIS2_CALL
 woden_wsdl10_soap_header_block_add_ext_element(
@@ -220,7 +220,7 @@
 woden_wsdl10_soap_header_block_has_ext_elements_for_namespace(
     void *header_block,
     const axutil_env_t *env,
-    axis2_uri_t *namespc);
+    axutil_uri_t *namespc);
 
 /* ************************************************************
  *  Non-API implementation methods
@@ -1138,7 +1138,7 @@
 woden_wsdl10_soap_header_block_get_ext_attrs_for_namespace(
     void *header_block,
     const axutil_env_t *env,
-    axis2_uri_t *namespc)
+    axutil_uri_t *namespc)
 {
     woden_wsdl10_soap_header_block_impl_t *header_block_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -1174,7 +1174,7 @@
 woden_wsdl10_soap_header_block_has_ext_attrs_for_namespace(
     void *header_block,
     const axutil_env_t *env,
-    axis2_uri_t *namespc)
+    axutil_uri_t *namespc)
 {
     woden_wsdl10_soap_header_block_impl_t *header_block_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -1269,7 +1269,7 @@
 woden_wsdl10_soap_header_block_has_ext_elements_for_namespace(
     void *header_block,
     const axutil_env_t *env,
-    axis2_uri_t *namespc)
+    axutil_uri_t *namespc)
 {
     woden_wsdl10_soap_header_block_impl_t *header_block_impl = NULL;
     axutil_hash_t *super = NULL;

Modified: webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_module.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_module.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_module.c (original)
+++ webservices/axis2/trunk/c/woden/src/wsdl10/extensions/soap/woden_wsdl10_soap_module.c Fri Mar 30 12:54:08 2007
@@ -45,7 +45,7 @@
     axis2_bool_t f_required;
     void *f_attr_ext;
     void *f_elem_ext;
-    axis2_uri_t *f_ref;
+    axutil_uri_t *f_ref;
 };
 
 #define INTF_TO_IMPL(module) ((woden_wsdl10_soap_module_impl_t *) module)
@@ -69,7 +69,7 @@
  *  Component model methods (SOAPHeaderBlock interface), some shared with Element model
  * ***********************************************************************/
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_wsdl10_soap_module_get_ref(
     void *module,
     axutil_env_t *env);
@@ -97,7 +97,7 @@
 woden_wsdl10_soap_module_set_ref(
     void *module,
     axutil_env_t *env,
-    axis2_uri_t *uri);
+    axutil_uri_t *uri);
 
 axis2_status_t AXIS2_CALL
 woden_wsdl10_soap_module_set_parent_element(
@@ -181,7 +181,7 @@
 woden_wsdl10_soap_module_get_ext_attrs_for_namespace(
     void *module,
     axutil_env_t *env,
-    axis2_uri_t *namespc);
+    axutil_uri_t *namespc);
 
 axutil_array_list_t *AXIS2_CALL
 woden_wsdl10_soap_module_get_ext_attrs(
@@ -192,7 +192,7 @@
 woden_wsdl10_soap_module_has_ext_attrs_for_namespace(
     void *module,
     axutil_env_t *env,
-    axis2_uri_t *namespc);
+    axutil_uri_t *namespc);
 
 axis2_status_t AXIS2_CALL
 woden_wsdl10_soap_module_add_ext_element(
@@ -221,7 +221,7 @@
 woden_wsdl10_soap_module_has_ext_elements_for_namespace(
     void *module,
     axutil_env_t *env,
-    axis2_uri_t *namespc);
+    axutil_uri_t *namespc);
 
 static woden_wsdl10_soap_module_t *
 create(const axutil_env_t *env);
@@ -629,7 +629,7 @@
 
     if (module_impl->f_ref)
     {
-        axis2_uri_free(module_impl->f_ref, env);
+        axutil_uri_free(module_impl->f_ref, env);
         module_impl->f_ref = NULL;
     }
 
@@ -726,7 +726,7 @@
  *  Component model methods (SOAPHeaderBlock interface), some shared with Element model
  * ***********************************************************************/
 
-axis2_uri_t *AXIS2_CALL
+axutil_uri_t *AXIS2_CALL
 woden_wsdl10_soap_module_get_ref(
     void *module,
     axutil_env_t *env)
@@ -799,7 +799,7 @@
 woden_wsdl10_soap_module_set_ref(
     void *module,
     axutil_env_t *env,
-    axis2_uri_t *uri)
+    axutil_uri_t *uri)
 {
     woden_wsdl10_soap_module_impl_t *module_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -812,11 +812,11 @@
 
     if (module_impl->f_ref)
     {
-        axis2_uri_free(module_impl->f_ref, env);
+        axutil_uri_free(module_impl->f_ref, env);
         module_impl->f_ref = NULL;
     }
 
-    module_impl->f_ref = axis2_uri_clone(uri, env);
+    module_impl->f_ref = axutil_uri_clone(uri, env);
 
     return AXIS2_SUCCESS;
 
@@ -1087,7 +1087,7 @@
 woden_wsdl10_soap_module_get_ext_attrs_for_namespace(
     void *module,
     axutil_env_t *env,
-    axis2_uri_t *namespc)
+    axutil_uri_t *namespc)
 {
     woden_wsdl10_soap_module_impl_t *module_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -1123,7 +1123,7 @@
 woden_wsdl10_soap_module_has_ext_attrs_for_namespace(
     void *module,
     axutil_env_t *env,
-    axis2_uri_t *namespc)
+    axutil_uri_t *namespc)
 {
     woden_wsdl10_soap_module_impl_t *module_impl = NULL;
     axutil_hash_t *super = NULL;
@@ -1218,7 +1218,7 @@
 woden_wsdl10_soap_module_has_ext_elements_for_namespace(
     void *module,
     axutil_env_t *env,
-    axis2_uri_t *namespc)
+    axutil_uri_t *namespc)
 {
     woden_wsdl10_soap_module_impl_t *module_impl = NULL;
     axutil_hash_t *super = NULL;



---------------------------------------------------------------------
To unsubscribe, e-mail: axis-cvs-unsubscribe@ws.apache.org
For additional commands, e-mail: axis-cvs-help@ws.apache.org
--- webservices/axis2/trunk/c/woden/src/builder/woden_reader.c (original)
+++ webservices/axis2/trunk/c/woden/src/builder/woden_reader.c Fri Mar 30 12:54:08 2007
@@ -115,7 +115,7 @@
 #include <axiom_stax_builder.h>
 #include <axiom_xml_reader.h>
 #include <axiom_util.h>
-#include <axis2_utils.h>
+#include <axutil_utils.h>
 #include <axutil_generic_obj.h>
 
 #include <axutil_string_util.h>
@@ -135,7 +135,7 @@
     /* A map of imported schema definitions keyed by schema location URI */
     axutil_hash_t *f_imported_schemas;
     woden_ext_registry_t *f_ext_reg;
-    axis2_uri_t *f_temp_uri;
+    axutil_uri_t *f_temp_uri;
 
 };
 
@@ -434,11 +434,11 @@
     axutil_hash_t *wsdl_modules);
 
 /*
  * Convert a string of type xs:anyURI to a axis2_uri.
  * An empty string argument will return an empty string URI.
  * A null argument will return a null.
  */
-static axis2_uri_t *
+static axutil_uri_t *
 get_uri(
     const axutil_env_t *env,
     const axis2_char_t *uri_str);
@@ -505,7 +505,7 @@
 
     if (reader_impl->f_temp_uri)
     {
-        axis2_uri_free(reader_impl->f_temp_uri, env);
+        axutil_uri_free(reader_impl->f_temp_uri, env);
         reader_impl->f_temp_uri = NULL;
     }
 
@@ -616,7 +616,7 @@
     woden_reader_impl_t *reader_impl = NULL;
     void *desc = NULL;
     void *ext_reg = NULL;
-    axis2_uri_t *uri = NULL;
+    axutil_uri_t *uri = NULL;
     axis2_char_t *target_namespc = NULL;
     axiom_element_t *desc_el = NULL;
     axutil_hash_t *attrs = NULL;
@@ -661,7 +661,7 @@
 
     uri = get_uri(env, document_base_uri);
     WODEN_DESC_ELEMENT_SET_DOCUMENT_BASE_URI(desc, env, uri);
-    axis2_uri_free(uri, env);
+    axutil_uri_free(uri, env);
     uri = NULL;
 
     desc_el = AXIOM_NODE_GET_DATA_ELEMENT(desc_el_node, env);
@@ -670,11 +670,11 @@
 
     if (target_namespc)
     {
-        axis2_uri_t *target_namespc_uri = NULL;
+        axutil_uri_t *target_namespc_uri = NULL;
 
         target_namespc_uri = get_uri(env, target_namespc);
         WODEN_DESC_ELEMENT_SET_TARGET_NAMESPACE(desc, env, target_namespc_uri);
-        axis2_uri_free(target_namespc_uri, env);
+        axutil_uri_free(target_namespc_uri, env);
     }
 
     /* parse the namespace declarations */
@@ -710,7 +710,7 @@
                 WODEN_DESC_ELEMENT_ADD_NAMESPACE(desc, env, NULL, uri);
             }
         }
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
         uri = NULL;
 
     }
@@ -950,24 +950,24 @@
 
     if (namespc_uri)
     {
-        axis2_uri_t *uri = NULL;
+        axutil_uri_t *uri = NULL;
 
         /* TODO handle missing namespace attribute (REQUIRED attr) */
         uri = get_uri(env, namespc_uri);
         WODEN_IMPORT_SET_NAMESPACE(imp, env, uri);
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
     }
 
     if (location_uri)
     {
-        axis2_uri_t *uri = NULL;
+        axutil_uri_t *uri = NULL;
         void *imported_desc = NULL;
 
         /* TODO handle missing locationURI (OPTIONAL attr) */
         imp = woden_import_to_import_element(imp, env);
         uri = get_uri(env, location_uri);
         WODEN_IMPORT_ELEMENT_SET_LOCATION(imp, env, uri);
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
 
         imported_desc = get_wsdl_from_location(reader, env, location_uri, desc,
                 wsdl_modules);
@@ -1004,13 +1004,13 @@
 
     if (location_uri)
     {
-        axis2_uri_t *uri = NULL;
+        axutil_uri_t *uri = NULL;
         void *included_desc = NULL;
 
         uri = get_uri(env, location_uri);
         include = woden_include_to_include_element(include, env);
         WODEN_INCLUDE_ELEMENT_SET_LOCATION(include, env, uri);
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
 
         included_desc = get_wsdl_from_location(reader, env, location_uri, desc,
                 wsdl_modules);
@@ -1123,7 +1123,7 @@
     void *schema = woden_inlined_schema_create(env);
     axis2_char_t *attr_id = NULL;
     axis2_char_t *tns = NULL;
-    axis2_uri_t *base_uri = NULL;
+    axutil_uri_t *base_uri = NULL;
     axis2_char_t *base_uri_str = NULL;
     xml_schema_t *schema_def = NULL;
     xml_schema_collection_t *xsc = NULL;
@@ -1139,14 +1139,14 @@
     if (tns)
     {
         void *base = WODEN_INLINED_SCHEMA_GET_BASE_IMPL(schema, env);
-        axis2_uri_t *uri = get_uri(env, tns);
+        axutil_uri_t *uri = get_uri(env, tns);
         WODEN_SCHEMA_SET_NAMESPACE(base, env, uri);
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
     }
     desc = woden_desc_to_desc_element(desc, env);
     base_uri = WODEN_DESC_ELEMENT_GET_DOCUMENT_BASE_URI(desc, env);
     if (base_uri)
-        base_uri_str = axis2_uri_to_string(base_uri, env,
+        base_uri_str = axutil_uri_to_string(base_uri, env,
                 AXIS2_URI_UNP_OMITUSERINFO);
 
     xsc = xml_schema_collection_create(env);
@@ -1203,9 +1203,9 @@
     axis2_char_t *ns = NULL;
     axis2_char_t *sloc = NULL;
     axis2_char_t *schema_uri = NULL;
-    axis2_uri_t *uri = NULL;
+    axutil_uri_t *uri = NULL;
     void *schema_def = NULL;
-    axis2_uri_t *context_uri = NULL;
+    axutil_uri_t *context_uri = NULL;
     axis2_char_t *schema_loc = NULL;
     axiom_element_t *import_el = NULL;
 
@@ -1224,7 +1224,7 @@
         uri = get_uri(env, ns);
         schema = woden_imported_schema_to_schema(schema, env);
         WODEN_SCHEMA_SET_NAMESPACE(schema, env, uri);
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
         uri = NULL;
     }
     sloc = axiom_element_get_attribute_value_by_name(import_el, env,
@@ -1233,7 +1233,7 @@
     {
         uri = get_uri(env, sloc);
         WODEN_IMPORTED_SCHEMA_SET_LOCATION(schema, env, uri);
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
         uri = NULL;
     }
 
@@ -1261,8 +1261,8 @@
     desc = woden_desc_to_desc_element(desc, env);
     context_uri = WODEN_DESC_ELEMENT_GET_DOCUMENT_BASE_URI(desc, env);
     uri = WODEN_IMPORTED_SCHEMA_GET_LOCATION(schema, env);
-    schema_loc = axis2_uri_to_string(uri, env, AXIS2_URI_UNP_OMITUSERINFO);
-    uri = axis2_uri_parse_relative(env, context_uri, schema_loc);
+    schema_loc = axutil_uri_to_string(uri, env, AXIS2_URI_UNP_OMITUSERINFO);
+    uri = axutil_uri_parse_relative(env, context_uri, schema_loc);
     if (AXIS2_SUCCESS != AXIS2_ERROR_GET_STATUS_CODE(env->error))
     {
         /* can't continue schema retrieval with a bad URL.*/
@@ -1270,7 +1270,7 @@
         return schema;
     }
 
-    schema_uri = axis2_uri_to_string(uri, env, AXIS2_URI_UNP_OMITUSERINFO);
+    schema_uri = axutil_uri_to_string(uri, env, AXIS2_URI_UNP_OMITUSERINFO);
 
     /* If the schema has already been imported, reuse it. */
     schema_def = axutil_hash_get(reader_impl->f_imported_schemas, schema_uri,
@@ -1354,11 +1354,11 @@
     if (name)
     {
         axutil_qname_t *qname = NULL;
-        axis2_uri_t *namespc = NULL;
+        axutil_uri_t *namespc = NULL;
         axis2_char_t *namespc_str = NULL;
 
         namespc = WODEN_DESC_ELEMENT_GET_TARGET_NAMESPACE(desc, env);
-        namespc_str = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+        namespc_str = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
         qname = axutil_qname_create(env, name, namespc_str, NULL);
         intface = woden_interface_to_interface_element(intface, env);
         WODEN_INTERFACE_ELEMENT_SET_QNAME(intface, env, qname);
@@ -1378,12 +1378,12 @@
             size = axutil_array_list_size(string_list, env);
         for (i = 0; i < size; i++)
         {
-            axis2_uri_t *uri = NULL;
+            axutil_uri_t *uri = NULL;
             uri_str = axutil_array_list_get(string_list, env, i);
             intface = woden_interface_to_interface_element(intface, env);
             uri = get_uri(env, uri_str);
             WODEN_INTERFACE_ELEMENT_ADD_STYLE_DEFAULT_URI(intface, env, uri);
-            axis2_uri_free(uri, env);
+            axutil_uri_free(uri, env);
         }
     }
 
@@ -1525,13 +1525,13 @@
     if (name)
     {
         axutil_qname_t *qname = NULL;
-        axis2_uri_t *ns = NULL;
+        axutil_uri_t *ns = NULL;
         axis2_char_t *ns_str = NULL;
 
         ns = WODEN_DESC_ELEMENT_GET_TARGET_NAMESPACE(desc, env);
         if (!ns)
             ns_str = WODEN_VALUE_EMPTY_STRING;
-        ns_str = axis2_uri_to_string(ns, env, AXIS2_URI_UNP_OMITUSERINFO);
+        ns_str = axutil_uri_to_string(ns, env, AXIS2_URI_UNP_OMITUSERINFO);
         qname = axutil_qname_create(env, name, ns_str, NULL);
         fault = woden_interface_fault_to_interface_fault_element(fault, env);
         WODEN_INTERFACE_FAULT_ELEMENT_SET_QNAME(fault, env, qname);
@@ -1651,11 +1651,11 @@
     if (name)
     {
         axutil_qname_t *qname = NULL;
-        axis2_uri_t *ns = NULL;
+        axutil_uri_t *ns = NULL;
         axis2_char_t *ns_str = NULL;
 
         ns = WODEN_DESC_ELEMENT_GET_TARGET_NAMESPACE(desc, env);
-        ns_str = axis2_uri_to_string(ns, env, AXIS2_URI_UNP_OMITUSERINFO);
+        ns_str = axutil_uri_to_string(ns, env, AXIS2_URI_UNP_OMITUSERINFO);
         qname = axutil_qname_create(env, name, ns_str, NULL);
         op = woden_interface_op_to_interface_op_element(op, env);
         WODEN_INTERFACE_OP_ELEMENT_SET_QNAME(op, env, qname);
@@ -1667,7 +1667,7 @@
     {
         axutil_array_list_t *str_list = NULL;
         axis2_char_t *uri_str = NULL;
-        axis2_uri_t *uri = NULL;
+        axutil_uri_t *uri = NULL;
         int i = 0, size = 0;
 
         size = axutil_array_list_size(str_list, env);
@@ -1678,7 +1678,7 @@
             uri = get_uri(env, uri_str);
             op = woden_interface_op_to_interface_op_element(op, env);
             WODEN_INTERFACE_OP_ELEMENT_ADD_STYLE_URI(op, env, uri);
-            axis2_uri_free(uri, env);
+            axutil_uri_free(uri, env);
         }
     }
 
@@ -1686,12 +1686,12 @@
 
     if (pat)
     {
-        axis2_uri_t *uri = NULL;
+        axutil_uri_t *uri = NULL;
 
         uri = get_uri(env, pat);
         op = woden_interface_op_to_interface_op_element(op, env);
         WODEN_INTERFACE_OP_ELEMENT_SET_PATTERN(op, env, uri);
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
     }
     op = woden_interface_op_to_attr_extensible(op, env);
     status = parse_ext_attributes(reader, env, op_el_node, "interface_op_element",
@@ -2257,11 +2257,11 @@
     if (name)
     {
         axutil_qname_t *qname = NULL;
-        axis2_uri_t *namespc = NULL;
+        axutil_uri_t *namespc = NULL;
         axis2_char_t *namespc_str = NULL;
 
         namespc = WODEN_DESC_ELEMENT_GET_TARGET_NAMESPACE(desc, env);
-        namespc_str = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+        namespc_str = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
         qname = axutil_qname_create(env, name, namespc_str, NULL);
         binding = woden_binding_to_binding_element(binding, env);
         WODEN_BINDING_ELEMENT_SET_QNAME(binding, env, qname);
@@ -2306,12 +2306,12 @@
 
     if (type)
     {
-        axis2_uri_t *uri = NULL;
+        axutil_uri_t *uri = NULL;
 
         uri = get_uri(env, type);
         binding = woden_binding_to_binding_element(binding, env);
         WODEN_BINDING_ELEMENT_SET_TYPE(binding, env, uri);
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
     }
 
     /* TODO extends attribute */
@@ -3245,11 +3245,11 @@
     if (name)
     {
         axutil_qname_t *qname = NULL;
-        axis2_uri_t *namespc = NULL;
+        axutil_uri_t *namespc = NULL;
         axis2_char_t *namespc_str = NULL;
 
         namespc = WODEN_DESC_ELEMENT_GET_TARGET_NAMESPACE(desc, env);
-        namespc_str = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+        namespc_str = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
         qname = axutil_qname_create(env, name, namespc_str, NULL);
         svc = woden_svc_to_svc_element(svc, env);
         WODEN_SVC_ELEMENT_SET_QNAME(svc, env, qname);
@@ -3456,12 +3456,12 @@
 
     if (address)
     {
-        axis2_uri_t *address_uri = NULL;
+        axutil_uri_t *address_uri = NULL;
 
         address_uri = get_uri(env, address);
         endpoint = woden_endpoint_to_endpoint_element(endpoint, env);
         WODEN_ENDPOINT_ELEMENT_SET_ADDRESS(endpoint, env, address_uri);
-        axis2_uri_free(address_uri, env);
+        axutil_uri_free(address_uri, env);
     }
 
     endpoint = woden_endpoint_to_attr_extensible(endpoint, env);
@@ -3565,10 +3565,10 @@
 
     if (ref)
     {
-        axis2_uri_t *ref_uri = get_uri(env, ref);
+        axutil_uri_t *ref_uri = get_uri(env, ref);
         feature = woden_feature_to_feature_element(feature, env);
         WODEN_FEATURE_ELEMENT_SET_REF(feature, env, ref_uri);
-        axis2_uri_free(ref_uri, env);
+        axutil_uri_free(ref_uri, env);
     }
 
     attr_req = axutil_qname_create_from_string(env, WODEN_ATTR_REQUIRED);
@@ -3686,10 +3686,10 @@
 
     if (ref)
     {
-        axis2_uri_t *ref_uri = get_uri(env, ref);
+        axutil_uri_t *ref_uri = get_uri(env, ref);
         property = woden_property_to_property_element(property, env);
         WODEN_PROPERTY_ELEMENT_SET_REF(property, env, ref_uri);
-        axis2_uri_free(ref_uri, env);
+        axutil_uri_free(ref_uri, env);
     }
 
     property = woden_property_to_attr_extensible(property, env);
@@ -3973,21 +3973,21 @@
     void *desc,
     axutil_hash_t *wsdl_modules)
 {
-    axis2_uri_t *context_uri = NULL;
-    axis2_uri_t *location_uri = NULL;
+    axutil_uri_t *context_uri = NULL;
+    axutil_uri_t *location_uri = NULL;
     axis2_char_t *location_str = NULL;
     void *referenced_desc = NULL;
     axiom_node_t *doc_el_node = NULL;
 
     desc = woden_desc_to_desc_element(desc, env);
     context_uri = WODEN_DESC_ELEMENT_GET_DOCUMENT_BASE_URI(desc, env);
-    location_uri = axis2_uri_parse_relative(env, context_uri, location_uri_str);
+    location_uri = axutil_uri_parse_relative(env, context_uri, location_uri_str);
     if (AXIS2_SUCCESS != AXIS2_ERROR_GET_STATUS_CODE(env->error))
     {
         /* Can't continue import with a bad URL.*/
         return NULL;
     }
-    location_str = axis2_uri_to_string(location_uri, env, AXIS2_URI_UNP_OMITUSERINFO);
+    location_str = axutil_uri_to_string(location_uri, env, AXIS2_URI_UNP_OMITUSERINFO);
 
     /* Check if WSDL imported or included previously from this location.*/
     referenced_desc = axutil_hash_get(wsdl_modules, location_str, AXIS2_HASH_KEY_STRING);
@@ -4035,11 +4035,11 @@
 }
 
 /*
  * Convert a string of type xs:anyURI to a axis2_uri.
  * An empty string argument will return an empty string URI.
  * A null argument will return a null.
  */
-static axis2_uri_t *
+static axutil_uri_t *
 get_uri(
     const axutil_env_t *env,
     const axis2_char_t *uri_str)
@@ -4047,6 +4047,6 @@
     AXIS2_ENV_CHECK(env, NULL);
     AXIS2_PARAM_CHECK(env->error, uri_str, NULL);
 
-    return axis2_uri_parse_string(env, uri_str);
+    return axutil_uri_parse_string(env, uri_str);
 }
 
@@ -434,11 +434,11 @@
 
 /*
- * Convert a string of type xs:anyURI to a axis2_uri.
+ * Convert a string of type xs:anyURI to a axutil_uri.
  * An empty string argument will return an empty string URI.
  * A null argument will return a null.
@@ -4035,11 +4035,11 @@
 
 /*
- * Convert a string of type xs:anyURI to a axis2_uri.
+ * Convert a string of type xs:anyURI to a axutil_uri.
  * An empty string argument will return an empty string URI.
  * A null argument will return a null.

Modified: webservices/axis2/trunk/c/woden/src/builder/woden_resolver.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/builder/woden_resolver.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================
--- webservices/axis2/trunk/c/woden/src/builder/wsdl10/woden_wsdl10_reader.c (original)
+++ webservices/axis2/trunk/c/woden/src/builder/wsdl10/woden_wsdl10_reader.c Fri Mar 30 12:54:08 2007
@@ -116,7 +116,7 @@
 #include <axiom_stax_builder.h>
 #include <axiom_xml_reader.h>
 #include <axiom_util.h>
-#include <axis2_utils.h>
+#include <axutil_utils.h>
 #include <axutil_generic_obj.h>
 
 #include <axutil_string_util.h>
@@ -432,11 +432,11 @@
     axutil_hash_t *wsdl_modules);
 
 /*
  * Convert a string of type xs:anyURI to a axis2_uri.
  * An empty string argument will return an empty string URI.
  * A null argument will return a null.
  */
-static axis2_uri_t *
+static axutil_uri_t *
 get_uri(
     const axutil_env_t *env,
     const axis2_char_t *uri_str);
@@ -607,7 +607,7 @@
     woden_wsdl10_reader_impl_t *reader_impl = NULL;
     void *desc = NULL;
     void *ext_reg = NULL;
-    axis2_uri_t *uri = NULL;
+    axutil_uri_t *uri = NULL;
     axis2_char_t *target_namespc = NULL;
     axiom_element_t *desc_el = NULL;
     axutil_hash_t *attrs = NULL;
@@ -654,7 +654,7 @@
 
     uri = get_uri(env, document_base_uri);
     WODEN_WSDL10_DESC_ELEMENT_SET_DOCUMENT_BASE_URI(desc, env, uri);
-    axis2_uri_free(uri, env);
+    axutil_uri_free(uri, env);
     uri = NULL;
 
     desc_el = AXIOM_NODE_GET_DATA_ELEMENT(desc_el_node, env);
@@ -663,11 +663,11 @@
 
     if (target_namespc)
     {
-        axis2_uri_t *target_namespc_uri = NULL;
+        axutil_uri_t *target_namespc_uri = NULL;
 
         target_namespc_uri = get_uri(env, target_namespc);
         WODEN_WSDL10_DESC_ELEMENT_SET_TARGET_NAMESPACE(desc, env, target_namespc_uri);
-        axis2_uri_free(target_namespc_uri, env);
+        axutil_uri_free(target_namespc_uri, env);
     }
 
     /* parse the namespace declarations */
@@ -703,7 +703,7 @@
                 WODEN_WSDL10_DESC_ELEMENT_ADD_NAMESPACE(desc, env, NULL, uri);
             }
         }
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
         uri = NULL;
 
     }
@@ -968,24 +968,24 @@
 
     if (namespc_uri)
     {
-        axis2_uri_t *uri = NULL;
+        axutil_uri_t *uri = NULL;
 
         /* TODO handle missing namespace attribute (REQUIRED attr) */
         uri = get_uri(env, namespc_uri);
         WODEN_IMPORT_SET_NAMESPACE(imp, env, uri);
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
     }
 
     if (location_uri)
     {
-        axis2_uri_t *uri = NULL;
+        axutil_uri_t *uri = NULL;
         void *imported_desc = NULL;
 
         /* TODO handle missing locationURI (OPTIONAL attr) */
         imp = woden_import_to_import_element(imp, env);
         uri = get_uri(env, location_uri);
         WODEN_IMPORT_ELEMENT_SET_LOCATION(imp, env, uri);
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
 
         imported_desc = get_wsdl_from_location(reader, env, location_uri, desc,
                 wsdl_modules);
@@ -1022,13 +1022,13 @@
 
     if (location_uri)
     {
-        axis2_uri_t *uri = NULL;
+        axutil_uri_t *uri = NULL;
         void *included_desc = NULL;
 
         uri = get_uri(env, location_uri);
         include = woden_include_to_include_element(include, env);
         WODEN_INCLUDE_ELEMENT_SET_LOCATION(include, env, uri);
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
 
         included_desc = get_wsdl_from_location(reader, env, location_uri, desc,
                 wsdl_modules);
@@ -1148,7 +1148,7 @@
     void *schema = NULL;
     axis2_char_t *attr_id = NULL;
     axis2_char_t *tns = NULL;
-    axis2_uri_t *base_uri = NULL;
+    axutil_uri_t *base_uri = NULL;
     axis2_char_t *base_uri_str = NULL;
     xml_schema_t *schema_def = NULL;
     xml_schema_collection_t *xsc = NULL;
@@ -1165,14 +1165,14 @@
     if (tns)
     {
         void *base = WODEN_INLINED_SCHEMA_GET_BASE_IMPL(schema, env);
-        axis2_uri_t *uri = get_uri(env, tns);
+        axutil_uri_t *uri = get_uri(env, tns);
         WODEN_SCHEMA_SET_NAMESPACE(base, env, uri);
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
     }
     desc = woden_wsdl10_desc_to_desc_element(desc, env);
     base_uri = WODEN_WSDL10_DESC_ELEMENT_GET_DOCUMENT_BASE_URI(desc, env);
     if (base_uri)
-        base_uri_str = axis2_uri_to_string(base_uri, env,
+        base_uri_str = axutil_uri_to_string(base_uri, env,
                 AXIS2_URI_UNP_OMITUSERINFO);
 
     xsc = xml_schema_collection_create(env);
@@ -1229,9 +1229,9 @@
     axis2_char_t *ns = NULL;
     axis2_char_t *sloc = NULL;
     axis2_char_t *schema_uri = NULL;
-    axis2_uri_t *uri = NULL;
+    axutil_uri_t *uri = NULL;
     void *schema_def = NULL;
-    axis2_uri_t *context_uri = NULL;
+    axutil_uri_t *context_uri = NULL;
     axis2_char_t *schema_loc = NULL;
     axiom_element_t *import_el = NULL;
     void *base_schema = NULL;
@@ -1251,7 +1251,7 @@
     {
         uri = get_uri(env, ns);
         WODEN_SCHEMA_SET_NAMESPACE(base_schema, env, uri);
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
         uri = NULL;
     }
     sloc = axiom_element_get_attribute_value_by_name(import_el, env,
@@ -1260,7 +1260,7 @@
     {
         uri = get_uri(env, sloc);
         WODEN_IMPORTED_SCHEMA_SET_LOCATION(schema, env, uri);
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
         uri = NULL;
     }
 
@@ -1289,8 +1289,8 @@
     desc = woden_wsdl10_desc_to_desc_element(desc, env);
     context_uri = WODEN_WSDL10_DESC_ELEMENT_GET_DOCUMENT_BASE_URI(desc, env);
     uri = WODEN_IMPORTED_SCHEMA_GET_LOCATION(schema, env);
-    schema_loc = axis2_uri_to_string(uri, env, AXIS2_URI_UNP_OMITUSERINFO);
-    uri = axis2_uri_parse_relative(env, context_uri, schema_loc);
+    schema_loc = axutil_uri_to_string(uri, env, AXIS2_URI_UNP_OMITUSERINFO);
+    uri = axutil_uri_parse_relative(env, context_uri, schema_loc);
     if (AXIS2_SUCCESS != AXIS2_ERROR_GET_STATUS_CODE(env->error))
     {
         void *base_schema = NULL;
@@ -1301,7 +1301,7 @@
         return schema;
     }
 
-    schema_uri = axis2_uri_to_string(uri, env, AXIS2_URI_UNP_OMITUSERINFO);
+    schema_uri = axutil_uri_to_string(uri, env, AXIS2_URI_UNP_OMITUSERINFO);
 
     /* If the schema has already been imported, reuse it. */
     schema_def = axutil_hash_get(reader_impl->f_imported_schemas, schema_uri,
@@ -1377,11 +1377,11 @@
     if (name)
     {
         axutil_qname_t *qname = NULL;
-        axis2_uri_t *namespc = NULL;
+        axutil_uri_t *namespc = NULL;
         axis2_char_t *namespc_str = NULL;
 
         namespc = WODEN_WSDL10_DESC_ELEMENT_GET_TARGET_NAMESPACE(desc, env);
-        namespc_str = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+        namespc_str = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
         qname = axutil_qname_create(env, name, namespc_str, NULL);
         msg = woden_wsdl10_msg_ref_to_msg_ref_element(msg, env);
         WODEN_WSDL10_MSG_REF_ELEMENT_SET_QNAME(msg, env, qname);
@@ -1501,11 +1501,11 @@
     if (name)
     {
         axutil_qname_t *qname = NULL;
-        axis2_uri_t *namespc = NULL;
+        axutil_uri_t *namespc = NULL;
         axis2_char_t *namespc_str = NULL;
 
         namespc = WODEN_WSDL10_DESC_ELEMENT_GET_TARGET_NAMESPACE(desc, env);
-        namespc_str = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+        namespc_str = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
         qname = axutil_qname_create(env, name, namespc_str, NULL);
         part = woden_wsdl10_part_to_part_element(part, env);
         WODEN_WSDL10_PART_ELEMENT_SET_QNAME(part, env, qname);
@@ -1603,11 +1603,11 @@
     if (name)
     {
         axutil_qname_t *qname = NULL;
-        axis2_uri_t *namespc = NULL;
+        axutil_uri_t *namespc = NULL;
         axis2_char_t *namespc_str = NULL;
 
         namespc = WODEN_WSDL10_DESC_ELEMENT_GET_TARGET_NAMESPACE(desc, env);
-        namespc_str = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+        namespc_str = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
         qname = axutil_qname_create(env, name, namespc_str, NULL);
         intface = woden_interface_to_interface_element(intface, env);
         WODEN_INTERFACE_ELEMENT_SET_QNAME(intface, env, qname);
@@ -1627,12 +1627,12 @@
             size = axutil_array_list_size(string_list, env);
         for (i = 0; i < size; i++)
         {
-            axis2_uri_t *uri = NULL;
+            axutil_uri_t *uri = NULL;
             uri_str = axutil_array_list_get(string_list, env, i);
             intface = woden_interface_to_interface_element(intface, env);
             uri = get_uri(env, uri_str);
             WODEN_INTERFACE_ELEMENT_ADD_STYLE_DEFAULT_URI(intface, env, uri);
-            axis2_uri_free(uri, env);
+            axutil_uri_free(uri, env);
         }
     }
 
@@ -1763,11 +1763,11 @@
     if (name)
     {
         axutil_qname_t *qname = NULL;
-        axis2_uri_t *ns = NULL;
+        axutil_uri_t *ns = NULL;
         axis2_char_t *ns_str = NULL;
 
         ns = WODEN_WSDL10_DESC_ELEMENT_GET_TARGET_NAMESPACE(desc, env);
-        ns_str = axis2_uri_to_string(ns, env, AXIS2_URI_UNP_OMITUSERINFO);
+        ns_str = axutil_uri_to_string(ns, env, AXIS2_URI_UNP_OMITUSERINFO);
         qname = axutil_qname_create(env, name, ns_str, NULL);
         op = woden_interface_op_to_interface_op_element(op, env);
         WODEN_INTERFACE_OP_ELEMENT_SET_QNAME(op, env, qname);
@@ -1779,7 +1779,7 @@
     {
         axutil_array_list_t *str_list = NULL;
         axis2_char_t *uri_str = NULL;
-        axis2_uri_t *uri = NULL;
+        axutil_uri_t *uri = NULL;
         int i = 0, size = 0;
 
         size = axutil_array_list_size(str_list, env);
@@ -1790,7 +1790,7 @@
             uri = get_uri(env, uri_str);
             op = woden_interface_op_to_interface_op_element(op, env);
             WODEN_INTERFACE_OP_ELEMENT_ADD_STYLE_URI(op, env, uri);
-            axis2_uri_free(uri, env);
+            axutil_uri_free(uri, env);
         }
     }
 
@@ -1798,12 +1798,12 @@
 
     if (pat)
     {
-        axis2_uri_t *uri = NULL;
+        axutil_uri_t *uri = NULL;
 
         uri = get_uri(env, pat);
         op = woden_interface_op_to_interface_op_element(op, env);
         WODEN_INTERFACE_OP_ELEMENT_SET_PATTERN(op, env, uri);
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
     }
     op = woden_interface_op_to_attr_extensible(op, env);
     status = parse_ext_attributes(reader, env, op_el_node, "interface_op_element",
@@ -1985,11 +1985,11 @@
     if (name)
     {
         axutil_qname_t *qname = NULL;
-        axis2_uri_t *namespc = NULL;
+        axutil_uri_t *namespc = NULL;
         axis2_char_t *namespc_str = NULL;
 
         namespc = WODEN_WSDL10_DESC_ELEMENT_GET_TARGET_NAMESPACE(desc, env);
-        namespc_str = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+        namespc_str = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
         qname = axutil_qname_create(env, name, namespc_str, NULL);
         fault_ref =
             woden_wsdl10_interface_fault_ref_to_interface_fault_ref_element(
@@ -2001,11 +2001,11 @@
     if (msg)
     {
         axutil_qname_t *qname = NULL;
-        axis2_uri_t *namespc = NULL;
+        axutil_uri_t *namespc = NULL;
         axis2_char_t *namespc_str = NULL;
 
         namespc = WODEN_WSDL10_DESC_ELEMENT_GET_TARGET_NAMESPACE(desc, env);
-        namespc_str = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+        namespc_str = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
         qname = axutil_qname_create(env, msg, namespc_str, NULL);
         fault_ref =
             woden_wsdl10_interface_fault_ref_to_interface_fault_ref_element(
@@ -2117,11 +2117,11 @@
     if (name)
     {
         axutil_qname_t *qname = NULL;
-        axis2_uri_t *namespc = NULL;
+        axutil_uri_t *namespc = NULL;
         axis2_char_t *namespc_str = NULL;
 
         namespc = WODEN_WSDL10_DESC_ELEMENT_GET_TARGET_NAMESPACE(desc, env);
-        namespc_str = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+        namespc_str = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
         qname = axutil_qname_create(env, name, namespc_str, NULL);
         msg_ref = woden_wsdl10_interface_msg_ref_to_interface_msg_ref_element(
                     msg_ref, env);
@@ -2132,7 +2132,7 @@
     if (msg)
     {
         axutil_qname_t *qname = NULL;
-        axis2_uri_t *namespc = NULL;
+        axutil_uri_t *namespc = NULL;
         axis2_char_t *namespc_str = NULL;
         axutil_array_list_t *msgs = NULL;
         int i = 0, size = 0;
@@ -2158,7 +2158,7 @@
             msg++;
         }
 
-        namespc_str = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+        namespc_str = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
         qname = axutil_qname_create(env, msg, namespc_str, NULL);
         msg_ref = woden_wsdl10_interface_msg_ref_to_interface_msg_ref_element(
                     msg_ref, env);
@@ -2262,11 +2262,11 @@
     if (name)
     {
         axutil_qname_t *qname = NULL;
-        axis2_uri_t *namespc = NULL;
+        axutil_uri_t *namespc = NULL;
         axis2_char_t *namespc_str = NULL;
 
         namespc = WODEN_WSDL10_DESC_ELEMENT_GET_TARGET_NAMESPACE(desc, env);
-        namespc_str = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+        namespc_str = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
         qname = axutil_qname_create(env, name, namespc_str, NULL);
         binding = woden_binding_to_binding_element(binding, env);
         WODEN_BINDING_ELEMENT_SET_QNAME(binding, env, qname);
@@ -2311,12 +2311,12 @@
 
     if (type)
     {
-        axis2_uri_t *uri = NULL;
+        axutil_uri_t *uri = NULL;
 
         uri = get_uri(env, type);
         binding = woden_binding_to_binding_element(binding, env);
         WODEN_BINDING_ELEMENT_SET_TYPE(binding, env, uri);
-        axis2_uri_free(uri, env);
+        axutil_uri_free(uri, env);
     }
 
     /* TODO extends attribute */
@@ -2442,11 +2442,11 @@
 
     if (name)
     {
-        axis2_uri_t *namespc = NULL;
+        axutil_uri_t *namespc = NULL;
         axis2_char_t *namespc_str = NULL;
 
         namespc = WODEN_WSDL10_DESC_ELEMENT_GET_TARGET_NAMESPACE(desc, env);
-        namespc_str = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+        namespc_str = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
         ref_qn = axutil_qname_create(env, name, namespc_str, NULL);
         op = woden_wsdl10_binding_op_to_binding_op_element(op, env);
         WODEN_WSDL10_BINDING_OP_ELEMENT_SET_QNAME(op, env, ref_qn);
@@ -2881,11 +2881,11 @@
     if (name)
     {
         axutil_qname_t *qname = NULL;
-        axis2_uri_t *namespc = NULL;
+        axutil_uri_t *namespc = NULL;
         axis2_char_t *namespc_str = NULL;
 
         namespc = WODEN_WSDL10_DESC_ELEMENT_GET_TARGET_NAMESPACE(desc, env);
-        namespc_str = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+        namespc_str = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
         qname = axutil_qname_create(env, name, namespc_str, NULL);
         msg_ref = woden_wsdl10_binding_msg_ref_to_binding_msg_ref_element(
                     msg_ref, env);
@@ -3045,11 +3045,11 @@
     if (name)
     {
         axutil_qname_t *qname = NULL;
-        axis2_uri_t *namespc = NULL;
+        axutil_uri_t *namespc = NULL;
         axis2_char_t *namespc_str = NULL;
 
         namespc = WODEN_WSDL10_DESC_ELEMENT_GET_TARGET_NAMESPACE(desc, env);
-        namespc_str = axis2_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
+        namespc_str = axutil_uri_to_string(namespc, env, AXIS2_URI_UNP_OMITUSERINFO);
         qname = axutil_qname_create(env, name, namespc_str, NULL);
         svc = woden_wsdl10_svc_to_svc_element(svc, env);
         WODEN_WSDL10_SVC_ELEMENT_SET_QNAME(svc, env, qname);
@@ -3265,12 +3265,12 @@
 
     if (address)
     {
-        axis2_uri_t *address_uri = NULL;
+        axutil_uri_t *address_uri = NULL;
 
         address_uri = get_uri(env, address);
         endpoint = woden_wsdl10_endpoint_to_endpoint_element(endpoint, env);
         WODEN_WSDL10_ENDPOINT_ELEMENT_SET_ADDRESS(endpoint, env, address_uri);
-        axis2_uri_free(address_uri, env);
+        axutil_uri_free(address_uri, env);
     }
 
     endpoint = woden_wsdl10_endpoint_to_attr_extensible(endpoint, env);
@@ -3375,10 +3375,10 @@
 
     if (ref)
     {
-        axis2_uri_t *ref_uri = get_uri(env, ref);
+        axutil_uri_t *ref_uri = get_uri(env, ref);
         feature = woden_feature_to_feature_element(feature, env);
         WODEN_FEATURE_ELEMENT_SET_REF(feature, env, ref_uri);
-        axis2_uri_free(ref_uri, env);
+        axutil_uri_free(ref_uri, env);
     }
 
     attr_req = axutil_qname_create_from_string(env, WODEN_WSDL10_ATTR_REQUIRED);
@@ -3503,10 +3503,10 @@
 
     if (ref)
     {
-        axis2_uri_t *ref_uri = get_uri(env, ref);
+        axutil_uri_t *ref_uri = get_uri(env, ref);
         property = woden_property_to_property_element(property, env);
         WODEN_PROPERTY_ELEMENT_SET_REF(property, env, ref_uri);
-        axis2_uri_free(ref_uri, env);
+        axutil_uri_free(ref_uri, env);
     }
 
     property = woden_property_to_attr_extensible(property, env);
@@ -3803,21 +3803,21 @@
     void *desc,
     axutil_hash_t *wsdl_modules)
 {
-    axis2_uri_t *context_uri = NULL;
-    axis2_uri_t *location_uri = NULL;
+    axutil_uri_t *context_uri = NULL;
+    axutil_uri_t *location_uri = NULL;
     axis2_char_t *location_str = NULL;
     void *referenced_desc = NULL;
     axiom_node_t *doc_el_node = NULL;
 
     desc = woden_wsdl10_desc_to_desc_element(desc, env);
     context_uri = WODEN_WSDL10_DESC_ELEMENT_GET_DOCUMENT_BASE_URI(desc, env);
-    location_uri = axis2_uri_parse_relative(env, context_uri, location_uri_str);
+    location_uri = axutil_uri_parse_relative(env, context_uri, location_uri_str);
     if (AXIS2_SUCCESS != AXIS2_ERROR_GET_STATUS_CODE(env->error))
     {
         /* Can't continue import with a bad URL.*/
         return NULL;
     }
-    location_str = axis2_uri_to_string(location_uri, env, AXIS2_URI_UNP_OMITUSERINFO);
+    location_str = axutil_uri_to_string(location_uri, env, AXIS2_URI_UNP_OMITUSERINFO);
 
     /* Check if WSDL imported or included previously from this location.*/
     referenced_desc = axutil_hash_get(wsdl_modules, location_str, AXIS2_HASH_KEY_STRING);
@@ -3865,11 +3865,11 @@
 }
 
 /*
  * Convert a string of type xs:anyURI to a axis2_uri.
  * An empty string argument will return an empty string URI.
  * A null argument will return a null.
  */
-static axis2_uri_t *
+static axutil_uri_t *
 get_uri(
     const axutil_env_t *env,
     const axis2_char_t *uri_str)
@@ -3877,6 +3877,6 @@
     AXIS2_ENV_CHECK(env, NULL);
     AXIS2_PARAM_CHECK(env->error, uri_str, NULL);
 
-    return axis2_uri_parse_string(env, uri_str);
+    return axutil_uri_parse_string(env, uri_str);
 }
 
@@ -432,11 +432,11 @@
 
 /*
- * Convert a string of type xs:anyURI to a axis2_uri.
+ * Convert a string of type xs:anyURI to a axutil_uri.
  * An empty string argument will return an empty string URI.
  * A null argument will return a null.
@@ -3865,11 +3865,11 @@
 
 /*
- * Convert a string of type xs:anyURI to a axis2_uri.
+ * Convert a string of type xs:anyURI to a axutil_uri.
  * An empty string argument will return an empty string URI.
  * A null argument will return a null.

Modified: webservices/axis2/trunk/c/woden/src/schema/woden_imported_schema.c
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/c/woden/src/schema/woden_imported_schema.c?view=diff&rev=524255&r1=524254&r2=524255
==============================================================================